==> prestashop_1.4.9.0.zip: prestashop/modules/jirafe/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{jirafe}prestashop>adminjirafedashboard14_2938c7f7e560ed972f8a4f68e80ff834'] = 'Tableau de bord';
$_MODULE['<{jirafe}prestashop>adminjirafedashboard15_2938c7f7e560ed972f8a4f68e80ff834'] = 'Tableau de bord';
$_MODULE['<{jirafe}prestashop>jirafe14_82add7330a3c66e05500eeccd39aa469'] = 'Analytique pour e-commerce';
$_MODULE['<{jirafe}prestashop>jirafe14_f93559b97ae7a2b76690eba69254919c'] = 'Le meilleur outil analytique pour les marchands e-commerce parfaitement intégré à la plateforme PrestaShop.';
$_MODULE['<{jirafe}prestashop>jirafe14_3500917073661abe35d86b0575fa1a7d'] = 'Êtes vous sûr de vouloir retirer l\'intégration Jirafe Analytics de votre site ?';
$_MODULE['<{jirafe}prestashop>jirafe14_fd1a630991b8c193765c69892543555d'] = 'Le webservice Jirafe n\'est pas accessible. Veuillez réessayer quand la connexion sera restaurée. ';
$_MODULE['<{jirafe}prestashop>jirafe15_82add7330a3c66e05500eeccd39aa469'] = 'Analytique pour e-commerce';
$_MODULE['<{jirafe}prestashop>jirafe15_f93559b97ae7a2b76690eba69254919c'] = 'Le meilleur outil analytique pour les marchands e-commerce parfaitement intégré à la plateforme PrestaShop.';
$_MODULE['<{jirafe}prestashop>jirafe15_3500917073661abe35d86b0575fa1a7d'] = 'Êtes vous sûr de vouloir retirer l\'intégration Jirafe Analytics de votre site ?';
$_MODULE['<{jirafe}prestashop>jirafe15_fd1a630991b8c193765c69892543555d'] = 'Le webservice Jirafe n\'est pas accessible. Veuillez réessayer quand la connexion sera restaurée. ';

==> prestashop_1.4.10.0.zip: prestashop/modules/jirafe/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{jirafe}prestashop>adminjirafedashboard14_2938c7f7e560ed972f8a4f68e80ff834'] = 'Tableau de bord';
$_MODULE['<{jirafe}prestashop>adminjirafedashboard15_2938c7f7e560ed972f8a4f68e80ff834'] = 'Tableau de bord';
$_MODULE['<{jirafe}prestashop>jirafe14_82add7330a3c66e05500eeccd39aa469'] = 'Analytique pour e-commerce';
$_MODULE['<{jirafe}prestashop>jirafe14_f93559b97ae7a2b76690eba69254919c'] = 'Le meilleur outil analytique pour les marchands e-commerce parfaitement intégré à la plateforme PrestaShop.';
$_MODULE['<{jirafe}prestashop>jirafe14_3500917073661abe35d86b0575fa1a7d'] = 'Êtes vous sûr de vouloir retirer l\'intégration Jirafe Analytics de votre site ?';
$_MODULE['<{jirafe}prestashop>jirafe14_81222118f1486714cc9de5ef126ebac9'] = 'allow_url_fopen doit être activé sur votre serveur pour utiliser ce module.';
$_MODULE['<{jirafe}prestashop>jirafe14_9d5b40ff49295ac0b4a5a13a88ccd285'] = 'L\'extension cURL doit être activé sur votre serveur pour utiliser ce module.';
$_MODULE['<{jirafe}prestashop>jirafe14_fd1a630991b8c193765c69892543555d'] = 'Le webservice Jirafe n\'est pas accessible. Veuillez réessayer quand la connexion sera restaurée. ';
$_MODULE['<{jirafe}prestashop>jirafe14_94a08da1fecbb6e8b46990538c7b50b2'] = 'Jetton';
$_MODULE['<{jirafe}prestashop>jirafe14_d8e87c0927539672f54462c837be0b7f'] = 'Sync';
$_MODULE['<{jirafe}prestashop>jirafe15_82add7330a3c66e05500eeccd39aa469'] = 'Analytique pour e-commerce';
$_MODULE['<{jirafe}prestashop>jirafe15_f93559b97ae7a2b76690eba69254919c'] = 'Le meilleur outil analytique pour les marchands e-commerce parfaitement intégré à la plateforme PrestaShop.';
$_MODULE['<{jirafe}prestashop>jirafe15_3500917073661abe35d86b0575fa1a7d'] = 'Êtes vous sûr de vouloir retirer l\'intégration Jirafe Analytics de votre site ?';
$_MODULE['<{jirafe}prestashop>jirafe15_81222118f1486714cc9de5ef126ebac9'] = 'allow_url_fopen doit être activé sur votre serveur pour utiliser ce module.';
$_MODULE['<{jirafe}prestashop>jirafe15_9d5b40ff49295ac0b4a5a13a88ccd285'] = 'L\'extension cURL doit être activé sur votre serveur pour utiliser ce module.';
$_MODULE['<{jirafe}prestashop>jirafe15_fd1a630991b8c193765c69892543555d'] = 'Le webservice Jirafe n\'est pas accessible. Veuillez réessayer quand la connexion sera restaurée. ';
